==> plusser_0.3-5.tar.gz: plusser/man/plusser.Rd <==
\docType{package}
\name{plusser}
\alias{plusser}
\alias{plusser-package}
\title{plusser: A Google+ API Interface for R}
\description{
The idea of this package is to provide a high level
interface to Google's Google+ social network. As of now,
functions related to data retrieval are available. The
authentication (beyond using an API key) and posting
messages parts of the API are not yet implemented.
}
\details{
As a high-level interface between R and Google+, this
package is aimed at social media and researchers. Google
does not provide an API to retrieve the following relation
ships without full authentication, this package is not yet
suitable for social network analysis.

On the social media side, this package can be used to
retrieve posts, a post's popularity (comments, +1s,
reshares) and the profiles of entities. Espescially
interesting might be the retrieval of profiles that
interacted with certain posts.
}
\section{Google+ API Key}{
  This section describes briefly how to obtain a Google+
  API key. \enumerate{ \item Go to the Google Developers
  Console at
  \url{https://console.developers.google.com/project}.
  \item Create a new project and open it.  \item In the
  menu, choose \code{APIs & auth}.  \item Choose Google+
  API on the next screen.  \item Activate it by clicking
  \code{On}.  \item Choose credentials from the submenu.
  \item Click \code{Create new key} and write it down. This
  is your API key. }
}

\section{Google+ Quotas}{
  Currently, Google permits 5 requests per second up to a
  maximum total of 10,000 requests per day.
}
\references{
See the official Google Google+ API documentation:
\url{https://developers.google.com/+/api/latest/}.
}

==> plusser_0.4-0.tar.gz: plusser/man/plusser.Rd <==
\docType{package}
\name{plusser}
\alias{plusser}
\alias{plusser-package}
\title{plusser: A Google+ API Interface for R}
\description{
The idea of this package is to provide a high level
interface to Google's Google+ social network. As of now,
functions related to data retrieval are available. The
authentication (beyond using an API key) and posting
messages parts of the API are not yet implemented.
}
\details{
As a high-level interface between R and Google+, this
package is aimed at social media and researchers. Google
does not provide an API to retrieve the following relation
ships without full authentication, this package is not yet
suitable for social network analysis.

On the social media side, this package can be used to
retrieve posts, a post's popularity (comments, +1s,
reshares) and the profiles of entities. Espescially
interesting might be the retrieval of profiles that
interacted with certain posts.

This package is designed as modular as possible with
separating harvest and parsing functions. Users can use
their own parsing functions if required.
}
\section{Google+ API Key}{
  This section describes briefly how to obtain a Google+
  API key. \enumerate{ \item Go to the Google Developers
  Console at
  \url{https://console.developers.google.com/project}.
  \item Create a new project and open it.  \item In the
  menu, choose \code{APIs & auth}.  \item Choose Google+
  API on the next screen.  \item Activate it by clicking
  \code{On}.  \item Choose credentials from the submenu.
  \item Click \code{Create new key} and write it down. This
  is your API key. }
}

\section{Google+ Quotas}{
  Currently, Google permits 5 requests per second up to a
  maximum total of 10,000 requests per day.
}
\references{
See the official Google Google+ API documentation:
\url{https://developers.google.com/+/api/latest/}.
}
